@@ -16,21 +16,32 @@ REGIONS = {
     "K417N": "NC_045512:22811-22813",
     "K417T": "NC_045512:22811-22813",
     "N439K": "NC_045512:22877-22879",
+    "N440K": "NC_045512:22880-22882",
+    "G446S": "NC_045512:22898-22900",
     "L452R": "NC_045512:22916-22918",
     "Y449H": "NC_045512:22907-22909",
+    "Y449N": "NC_045512:22907-22909",
     "Y453F": "NC_045512:22919-22921",
     "S477N": "NC_045512:22991-22993",
     "T478K": "NC_045512:22994-22996",
     "T478R": "NC_045512:22994-22996",
+    "E484A": "NC_045512:23012-23014",
     "E484K": "NC_045512:23012-23014",
     "E484Q": "NC_045512:23012-23014",
+    "F490R": "NC_045512:23030-23032",
+    "Q493K": "NC_045512:23039-23041",
+    "G496S": "NC_045512:23048-23050",
+    "Q498R": "NC_045512:23054-23056",
     "N501Y": "NC_045512:23063-23065",
+    "Y505H": "NC_045512:23075-23077",
+    "T547K": "NC_045512:23201-23203",
     "A570D": "NC_045512:23270-23272",
     "Q613H": "NC_045512:23399-23401",
     "D614G": "NC_045512:23402-23404",
     "A626S": "NC_045512:23438-23441",
     "H655Y": "NC_045512:23525-23527",
     "Q677H": "NC_045512:23591-23593",
+    "N679K": "NC_045512:23597-23599",
     "P681H": "NC_045512:23603-23605",
     "P681R": "NC_045512:23603-23605",
     "I692V": "NC_045512:23636-23638",
